==> dart_6.9.5.orig.tar.xz: dart-6.9.5/dart/common/VersionCounter.cpp <==
/*
 * Copyright (c) 2011-2019, The DART development contributors
 * All rights reserved.
 *
 * The list of contributors can be found at:
 *   https://github.com/dartsim/dart/blob/master/LICENSE
 *
 * This file is provided under the following "BSD-style" License:
 *   Redistribution and use in source and binary forms, with or
 *   without modification, are permitted provided that the following
 *   conditions are met:
 *   * Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *   * Redistributions in binary form must reproduce the above
 *     copyright notice, this list of conditions and the following
 *     disclaimer in the documentation and/or other materials provided
 *     with the distribution.
 *   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
 *   CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 *   INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 *   MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 *   DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR
 *   CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 *   SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 *   LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 *   USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 *   AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 *   LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 *   ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 *   POSSIBILITY OF SUCH DAMAGE.
 */

#include "dart/common/VersionCounter.hpp"
#include "dart/common/Console.hpp"

#include <iostream>
#include <cassert>

namespace dart {
namespace common {

//==============================================================================
VersionCounter::VersionCounter()
  : mVersion(0),
    mDependent(nullptr)
{
  // Do nothing
}

//==============================================================================
std::size_t VersionCounter::incrementVersion()
{
  ++mVersion;
  if(mDependent)
    mDependent->incrementVersion();

  return mVersion;
}

//==============================================================================
std::size_t VersionCounter::getVersion() const
{
  return mVersion;
}

//==============================================================================
void VersionCounter::setVersionDependentObject(VersionCounter* dependent)
{
  VersionCounter* next = dependent;
  do
  {
    if(next == this)
    {
      dterr << "[VersionCounter::setVersionDependentObject] Attempting to "
            << "create a circular version dependency with the following loop:\n";
      next = dependent;
      while(next != this)
      {
        std::cerr << " -- " << next << "\n";
        next = next->mDependent;
      }
      std::cerr << " -- " << this << "\n";
      assert(false);
      return;
    }

    next = next->mDependent;
  } while(next);

  mDependent = dependent;
}

} // namespace common
} // namespace dart

==> dart_6.12.1+dfsg4.orig.tar.xz: dart-6.12.1/dart/common/VersionCounter.cpp <==
/*
 * Copyright (c) 2011-2021, The DART development contributors
 * All rights reserved.
 *
 * The list of contributors can be found at:
 *   https://github.com/dartsim/dart/blob/master/LICENSE
 *
 * This file is provided under the following "BSD-style" License:
 *   Redistribution and use in source and binary forms, with or
 *   without modification, are permitted provided that the following
 *   conditions are met:
 *   * Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *   * Redistributions in binary form must reproduce the above
 *     copyright notice, this list of conditions and the following
 *     disclaimer in the documentation and/or other materials provided
 *     with the distribution.
 *   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
 *   CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 *   INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 *   MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 *   DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR
 *   CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 *   SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 *   LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 *   USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 *   AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 *   LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 *   ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 *   POSSIBILITY OF SUCH DAMAGE.
 */

#include "dart/common/VersionCounter.hpp"

#include <cassert>
#include <iostream>

#include "dart/common/Console.hpp"

namespace dart {
namespace common {

//==============================================================================
VersionCounter::VersionCounter() : mVersion(0), mDependent(nullptr)
{
  // Do nothing
}

//==============================================================================
std::size_t VersionCounter::incrementVersion()
{
  ++mVersion;
  if (mDependent)
    mDependent->incrementVersion();

  return mVersion;
}

//==============================================================================
std::size_t VersionCounter::getVersion() const
{
  return mVersion;
}

//==============================================================================
void VersionCounter::setVersionDependentObject(VersionCounter* dependent)
{
  VersionCounter* next = dependent;
  do
  {
    if (next == this)
    {
      dterr
          << "[VersionCounter::setVersionDependentObject] Attempting to "
          << "create a circular version dependency with the following loop:\n";
      next = dependent;
      while (next != this)
      {
        std::cerr << " -- " << next << "\n";
        next = next->mDependent;
      }
      std::cerr << " -- " << this << "\n";
      assert(false);
      return;
    }

    next = next->mDependent;
  } while (next);

  mDependent = dependent;
}

} // namespace common
} // namespace dart
